@@ -52,7 +52,6 @@ package com.openexchange.messaging.sms.impl;
 import static com.openexchange.java.Autoboxing.B;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.settings.IValueHandler;
 import com.openexchange.groupware.settings.PreferencesItemService;
 import com.openexchange.groupware.settings.ReadOnlyValue;
@@ -61,6 +60,7 @@ import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.messaging.sms.osgi.MessagingSMSServiceRegistry;
 import com.openexchange.messaging.sms.service.MessagingNewService;
 import com.openexchange.session.Session;
+import com.openexchange.user.User;
 
 
 public class SMSPreferencesItem implements PreferencesItemService {
